@@ -1,7 +1,7 @@
 import pandas as pd
 import numpy as np
 import re
-from datasoap.unit_data.conversion import units
+# from unit_data.conversion import units
 
 
 class Soap:
@@ -105,6 +105,23 @@ class Soap:
 
     @staticmethod
     def convert_unit(line, unit_target):
+
+        units = {
+            'T': 10**12,
+            'G': 10**9,
+            'M': 10**6,
+            'k': 10**3,
+            'h': 10**2,
+            'da': 10**1,
+            'base': 1,
+            'd': 10**-1,
+            'c': 10**-2,
+            'm': 10**-3,
+            'µ': 10**-6,
+            'n': 10**-9,
+            'p': 10**-12
+        }
+
         # step 1: identify the suffix line -1
         for i in units.keys():
             print(f'i in convert_unit{i} \n units.keys{units.keys()}')
